==> appcarry_sdk-1.0.0.tar.gz: README.md <==
<img src="https://appcarry.com/assets/logos/logo-4.png"  width="200">

# appcarry_flutter

A Flutter plugin for AppCarry SDK.


🛠 In order for us to provide optimal support, we would kindly ask you to submit any issues to support@appcarry.com

When submitting an issue please specify your AppCarry sign-up (account) email , your app ID , reproduction steps, logs, code snippets and any additional relevant information.

---

### Table of content

- [Getting started](#getting-started)
- [Setting AppCarry options](#AppCarry-options)
- [Initializing the SDK](#init-sdk)
- [Guides](#guides)

### Supported Platforms

- Android
- iOS 8+

### This plugin is built for

- iOS AppCarrySDK **v1.0.0**

- Android AppCarrySDK **v1.0.0**

## <a id="getting-started"> **📲 Getting started**

In order to install the plugin, visit [this] page.

### <a id="AppCarry-options"> ⚙️  AppCarryOptions

To start using AppCarry you first need to create an instance of `AppCarrySdk` before using any other of our sdk functionalities.  

`AppCarrySdk` receives a map or `AppCarryOptions` object. This is how you can configure our `AppCarrySdk` instance and connect it to your AppCarry account.

*Example (using map):*
```dart
import 'package:appcarry_sdk/appcarry_sdk.dart';
//..

Map AppCarryOptions = { "acDevKey": acDevKey,
                "acAppId": appId,
                "isDebug": true};

AppCarrySdk AppCarrySdk = AppCarrySdk(AppCarryOptions);
```

### <a id="init-sdk"> 🚀  Initializing the SDK

The next step is to call `initSdk` which have the optional boolean parameters 
`registerConversionDataCallback`, 
`registerOnAppOpenAttributionCallback` and 
`registerOnDeepLinkingCallback` which are set to true as default.

After we call `initSdk` we can use all of AppCarry SDK features.

Initialize the SDK to enable AppCarry to detect installations, sessions (app opens) ,updates and use all of our features.

```dart
AppCarrySdk.initSdk(
    registerConversionDataCallback: true,
    registerOnAppOpenAttributionCallback: true,
    registerOnDeepLinkingCallback: true
);
```

## <a id="guides"> **📖 Guides**

Great installation and setup guides can be viewed [here]

==> appcarry_sdk-1.0.2.tar.gz: README.md <==
<img src="https://appcarry.com/assets/logos/logo-4.png"  width="200">

# appcarry_flutter

A Flutter plugin for AppCarry SDK.


🛠 In order for us to provide optimal support, we would kindly ask you to submit any issues to support@appcarry.com

When submitting an issue please specify your AppCarry sign-up (account) email , your app ID , reproduction steps, logs, code snippets and any additional relevant information.

---

### Table of content

- [Getting started](#getting-started)
- [Setting AppCarry options](#AppCarry-options)
- [Initializing the SDK](#init-sdk)
- [Guides](#guides)

### Supported Platforms

- Android
- iOS 8+

### This plugin is built for

- iOS AppCarrySDK **v1.0.0**

- Android AppCarrySDK **v1.0.0**

## <a id="getting-started"> **📲 Getting started**

In order to install the plugin, visit [this] page.

### <a id="AppCarry-options"> ⚙️  AppCarryOptions

To start using AppCarry you first need to create an instance of `AppCarrySdk` before using any other of our sdk functionalities.  

`AppCarrySdk` receives a map or `AppCarryOptions` object. This is how you can configure our `AppCarrySdk` instance and connect it to your AppCarry account.

*Example (using map):*
```dart
import 'package:appcarry_sdk/appcarry_sdk.dart';
//..

Map AppCarryOptions = { "acDevKey": acDevKey,
                "acAppId": appId,
                "isDebug": true};

AppCarrySdk AppCarrySdk = AppCarrySdk(AppCarryOptions);
```

### <a id="init-sdk"> 🚀  Initializing the SDK

The next step is to call `initSdk` which have the optional boolean parameters 
`registerConversionDataCallback`, 
`registerOnAppOpenAttributionCallback` and 
`registerOnDeepLinkingCallback` which are set to true as default.

After we call `initSdk` we can use all of AppCarry SDK features.

Initialize the SDK to enable AppCarry to detect installations, sessions (app opens) ,updates and use all of our features.

```dart
AppCarrySdk.initSdk(
    registerConversionDataCallback: true,
    registerOnAppOpenAttributionCallback: true
);
```

## <a id="guides"> **📖 Guides**

Great installation and setup guides can be viewed [here]
